@@ -1,16 +1,3 @@
-/***************************************************/
-/*! \class Mutex
-    \brief STK mutex class.
-
-    This class provides a uniform interface for
-    cross-platform mutex use.  On Linux and IRIX
-    systems, the pthread library is used. Under
-    Windows, critical sections are used.
-
-    by Perry R. Cook and Gary P. Scavone, 1995 - 2004.
-*/
-/***************************************************/
-
 #ifndef STK_MUTEX_H
 #define STK_MUTEX_H
 
@@ -31,6 +18,21 @@
 
 #endif
 
+namespace stk {
+
+/***************************************************/
+/*! \class Mutex
+    \brief STK mutex class.
+
+    This class provides a uniform interface for
+    cross-platform mutex use.  On Linux and IRIX
+    systems, the pthread library is used. Under
+    Windows, critical sections are used.
+
+    by Perry R. Cook and Gary P. Scavone, 1995 - 2010.
+*/
+/***************************************************/
+
 class Mutex : public Stk
 {
  public:
@@ -67,4 +69,6 @@ class Mutex : public Stk
 
 };
 
+} // stk namespace
+
 #endif
