@@ -18,14 +18,16 @@
        - Vibrato Gain = 1
        - Breath Pressure = 128
 
-    by Perry R. Cook and Gary P. Scavone, 1995 - 2004.
+    by Perry R. Cook and Gary P. Scavone, 1995 - 2010.
 */
 /***************************************************/
 
 #include "Clarinet.h"
 #include "SKINI.msg"
 
-Clarinet :: Clarinet(StkFloat lowestFrequency)
+namespace stk {
+
+Clarinet :: Clarinet( StkFloat lowestFrequency )
 {
   length_ = (long) (Stk::sampleRate() / lowestFrequency + 1);
   delayLine_.setMaximumDelay( length_ );
@@ -33,26 +35,23 @@ Clarinet :: Clarinet(StkFloat lowestFrequency)
   reedTable_.setOffset((StkFloat) 0.7);
   reedTable_.setSlope((StkFloat) -0.3);
 
-  // Concatenate the STK rawwave path to the rawwave file
-  vibrato_ = new WaveLoop( (Stk::rawwavePath() + "sinewave.raw").c_str(), true );
-  vibrato_->setFrequency((StkFloat) 5.735);
+  vibrato_.setFrequency((StkFloat) 5.735);
   outputGain_ = (StkFloat) 1.0;
   noiseGain_ = (StkFloat) 0.2;
   vibratoGain_ = (StkFloat) 0.1;
 }
 
-Clarinet :: ~Clarinet()
+Clarinet :: ~Clarinet( void )
 {
-  delete vibrato_;
 }
 
-void Clarinet :: clear()
+void Clarinet :: clear( void )
 {
   delayLine_.clear();
-  filter_.tick((StkFloat) 0.0);
+  filter_.tick( 0.0 );
 }
 
-void Clarinet :: setFrequency(StkFloat frequency)
+void Clarinet :: setFrequency( StkFloat frequency )
 {
   StkFloat freakency = frequency;
   if ( frequency <= 0.0 ) {
@@ -68,19 +67,19 @@ void Clarinet :: setFrequency(StkFloat frequency)
   delayLine_.setDelay(delay);
 }
 
-void Clarinet :: startBlowing(StkFloat amplitude, StkFloat rate)
+void Clarinet :: startBlowing( StkFloat amplitude, StkFloat rate )
 {
   envelope_.setRate(rate);
   envelope_.setTarget(amplitude); 
 }
 
-void Clarinet :: stopBlowing(StkFloat rate)
+void Clarinet :: stopBlowing( StkFloat rate )
 {
   envelope_.setRate(rate);
   envelope_.setTarget((StkFloat) 0.0); 
 }
 
-void Clarinet :: noteOn(StkFloat frequency, StkFloat amplitude)
+void Clarinet :: noteOn( StkFloat frequency, StkFloat amplitude )
 {
   this->setFrequency(frequency);
   this->startBlowing((StkFloat) 0.55 + (amplitude * (StkFloat) 0.30), amplitude * (StkFloat) 0.005);
@@ -92,7 +91,7 @@ void Clarinet :: noteOn(StkFloat frequency, StkFloat amplitude)
 #endif
 }
 
-void Clarinet :: noteOff(StkFloat amplitude)
+void Clarinet :: noteOff( StkFloat amplitude )
 {
   this->stopBlowing( amplitude * 0.01 );
 
@@ -102,42 +101,7 @@ void Clarinet :: noteOff(StkFloat amplitude)
 #endif
 }
 
-StkFloat Clarinet :: tick()
-{
-  StkFloat pressureDiff;
-  StkFloat breathPressure;
-
-  // Calculate the breath pressure (envelope + noise + vibrato)
-  breathPressure = envelope_.tick(); 
-  breathPressure += breathPressure * noiseGain_ * noise_.tick();
-  breathPressure += breathPressure * vibratoGain_ * vibrato_->tick();
-
-  // Perform commuted loss filtering.
-  pressureDiff = -0.95 * filter_.tick(delayLine_.lastOut());
-
-  // Calculate pressure difference of reflected and mouthpiece pressures.
-  pressureDiff = pressureDiff - breathPressure;
-
-  // Perform non-linear scattering using pressure difference in reed function.
-  lastOutput_ = delayLine_.tick(breathPressure + pressureDiff * reedTable_.tick(pressureDiff));
-
-  // Apply output gain.
-  lastOutput_ *= outputGain_;
-
-  return lastOutput_;
-}
-
-StkFloat *Clarinet :: tick(StkFloat *vector, unsigned int vectorSize)
-{
-  return Instrmnt::tick( vector, vectorSize );
-}
-
-StkFrames& Clarinet :: tick( StkFrames& frames, unsigned int channel )
-{
-  return Instrmnt::tick( frames, channel );
-}
-
-void Clarinet :: controlChange(int number, StkFloat value)
+void Clarinet :: controlChange( int number, StkFloat value )
 {
   StkFloat norm = value * ONE_OVER_128;
   if ( norm < 0 ) {
@@ -156,7 +120,7 @@ void Clarinet :: controlChange(int number, StkFloat value)
   else if (number == __SK_NoiseLevel_) // 4
     noiseGain_ = (norm * (StkFloat) 0.4);
   else if (number == __SK_ModFrequency_) // 11
-    vibrato_->setFrequency((norm * (StkFloat) 12.0));
+    vibrato_.setFrequency((norm * (StkFloat) 12.0));
   else if (number == __SK_ModWheel_) // 1
     vibratoGain_ = (norm * (StkFloat) 0.5);
   else if (number == __SK_AfterTouch_Cont_) // 128
@@ -171,3 +135,5 @@ void Clarinet :: controlChange(int number, StkFloat value)
     handleError( StkError::DEBUG_WARNING );
 #endif
 }
+
+} // stk namespace
