@@ -4,13 +4,15 @@
 
     This class implements an echo effect.
 
-    by Perry R. Cook and Gary P. Scavone, 1995 - 2004.
+    by Perry R. Cook and Gary P. Scavone, 1995 - 2010.
 */
 /***************************************************/
 
 #include "Echo.h"
 #include <iostream>
 
+namespace stk {
+
 Echo :: Echo( unsigned long maximumDelay ) : Effect()
 {
   this->setMaximumDelay( maximumDelay );
@@ -19,15 +21,10 @@ Echo :: Echo( unsigned long maximumDelay ) : Effect()
   this->clear();
 }
 
-Echo :: ~Echo()
-{
-}
-
-void Echo :: clear()
+void Echo :: clear( void )
 {
   delayLine_.clear();
-  lastOutput_[0] = 0.0;
-  lastOutput_[1] = 0.0;
+  lastFrame_[0] = 0.0;
 }
 
 void Echo :: setMaximumDelay( unsigned long delay )
@@ -54,20 +51,4 @@ void Echo :: setDelay( unsigned long delay )
   delayLine_.setDelay( size );
 }
 
-StkFloat Echo :: tick(StkFloat input)
-{
-  lastOutput_[0] = effectMix_ * delayLine_.tick(input);
-  lastOutput_[0] += input * (1.0 - effectMix_);
-  lastOutput_[1] = lastOutput_[0];
-  return lastOutput_[0];
-}
-
-StkFloat *Echo :: tick(StkFloat *vector, unsigned int vectorSize)
-{
-  return Effect::tick( vector, vectorSize );
-}
-
-StkFrames& Echo :: tick( StkFrames& frames, unsigned int channel )
-{
-  return Effect::tick( frames, channel );
-}
+} // stk namespace
