@@ -31,14 +31,16 @@
        - Vibrato Gain = 1
        - Breath Pressure = 128
 
-    by Perry R. Cook and Gary P. Scavone, 1995 - 2004.
+    by Perry R. Cook and Gary P. Scavone, 1995 - 2010.
 */
 /***************************************************/
 
 #include "Saxofony.h"
 #include "SKINI.msg"
 
-Saxofony :: Saxofony(StkFloat lowestFrequency)
+namespace stk {
+
+Saxofony :: Saxofony( StkFloat lowestFrequency )
 {
   length_ = (unsigned long) (Stk::sampleRate() / lowestFrequency + 1);
   // Initialize blowing position to 0.2 of length / 2.
@@ -51,28 +53,25 @@ Saxofony :: Saxofony(StkFloat lowestFrequency)
   reedTable_.setOffset( 0.7 );
   reedTable_.setSlope( 0.3 );
 
-  // Concatenate the STK rawwave path to the rawwave file
-  vibrato_ = new WaveLoop( (Stk::rawwavePath() + "sinewave.raw").c_str(), true );
-  vibrato_->setFrequency((StkFloat) 5.735);
+  vibrato_.setFrequency((StkFloat) 5.735);
 
   outputGain_ = 0.3;
   noiseGain_ = 0.2;
   vibratoGain_ = 0.1;
 }
 
-Saxofony :: ~Saxofony()
+Saxofony :: ~Saxofony( void )
 {
-  delete vibrato_;
 }
 
-void Saxofony :: clear()
+void Saxofony :: clear( void )
 {
   delays_[0].clear();
   delays_[1].clear();
   filter_.clear();
 }
 
-void Saxofony :: setFrequency(StkFloat frequency)
+void Saxofony :: setFrequency( StkFloat frequency )
 {
   StkFloat freakency = frequency;
   if ( frequency <= 0.0 ) {
@@ -89,7 +88,7 @@ void Saxofony :: setFrequency(StkFloat frequency)
   delays_[1].setDelay( position_ * delay );
 }
 
-void Saxofony :: setBlowPosition(StkFloat position)
+void Saxofony :: setBlowPosition( StkFloat position )
 {
   if ( position_ == position ) return;
 
@@ -104,19 +103,19 @@ void Saxofony :: setBlowPosition(StkFloat position)
   delays_[1].setDelay( position_ * totalDelay );
 }
 
-void Saxofony :: startBlowing(StkFloat amplitude, StkFloat rate)
+void Saxofony :: startBlowing( StkFloat amplitude, StkFloat rate )
 {
   envelope_.setRate( rate );
   envelope_.setTarget( amplitude );
 }
 
-void Saxofony :: stopBlowing(StkFloat rate)
+void Saxofony :: stopBlowing( StkFloat rate )
 {
   envelope_.setRate( rate );
   envelope_.setTarget( 0.0 );
 }
 
-void Saxofony :: noteOn(StkFloat frequency, StkFloat amplitude)
+void Saxofony :: noteOn( StkFloat frequency, StkFloat amplitude )
 {
   this->setFrequency( frequency );
   this->startBlowing( 0.55 + (amplitude * 0.30), amplitude * 0.005 );
@@ -128,7 +127,7 @@ void Saxofony :: noteOn(StkFloat frequency, StkFloat amplitude)
 #endif
 }
 
-void Saxofony :: noteOff(StkFloat amplitude)
+void Saxofony :: noteOff( StkFloat amplitude )
 {
   this->stopBlowing( amplitude * 0.01 );
 
@@ -138,38 +137,7 @@ void Saxofony :: noteOff(StkFloat amplitude)
 #endif
 }
 
-StkFloat Saxofony :: tick()
-{
-  StkFloat pressureDiff;
-  StkFloat breathPressure;
-  StkFloat temp;
-
-  // Calculate the breath pressure (envelope + noise + vibrato)
-  breathPressure = envelope_.tick(); 
-  breathPressure += breathPressure * noiseGain_ * noise_.tick();
-  breathPressure += breathPressure * vibratoGain_ * vibrato_->tick();
-
-  temp = -0.95 * filter_.tick( delays_[0].lastOut() );
-  lastOutput_ = temp - delays_[1].lastOut();
-  pressureDiff = breathPressure - lastOutput_;
-  delays_[1].tick( temp );
-  delays_[0].tick( breathPressure - (pressureDiff * reedTable_.tick(pressureDiff)) - temp );
-
-  lastOutput_ *= outputGain_;
-  return lastOutput_;
-}
-
-StkFloat *Saxofony :: tick(StkFloat *vector, unsigned int vectorSize)
-{
-  return Instrmnt::tick( vector, vectorSize );
-}
-
-StkFrames& Saxofony :: tick( StkFrames& frames, unsigned int channel )
-{
-  return Instrmnt::tick( frames, channel );
-}
-
-void Saxofony :: controlChange(int number, StkFloat value)
+void Saxofony :: controlChange( int number, StkFloat value )
 {
   StkFloat norm = value * ONE_OVER_128;
   if ( norm < 0 ) {
@@ -188,7 +156,7 @@ void Saxofony :: controlChange(int number, StkFloat value)
   else if (number == __SK_NoiseLevel_) // 4
     noiseGain_ = ( norm * 0.4 );
   else if (number == 29) // 29
-    vibrato_->setFrequency( norm * 12.0 );
+    vibrato_.setFrequency( norm * 12.0 );
   else if (number == __SK_ModWheel_) // 1
     vibratoGain_ = ( norm * 0.5 );
   else if (number == __SK_AfterTouch_Cont_) // 128
@@ -207,3 +175,5 @@ void Saxofony :: controlChange(int number, StkFloat value)
     handleError( StkError::DEBUG_WARNING );
 #endif
 }
+
+} // stk namespace
