@@ -12,13 +12,15 @@
        - Blowing Frequency Modulation = 2
        - Volume = 128
 
-    by Perry R. Cook  1996 - 2004.
+    by Perry R. Cook  1996 - 2010.
 */
 /***************************************************/
 
 #include "Whistle.h"
 #include "SKINI.msg"
-#include <math.h>
+#include <cmath>
+
+namespace stk {
 
 const int CAN_RADIUS = 100;
 const int PEA_RADIUS = 30;
@@ -33,11 +35,9 @@ const StkFloat SLOW_TICK_SIZE = 0.0001;
 
 const StkFloat ENV_RATE = 0.001;
 
-Whistle :: Whistle()
+Whistle :: Whistle( void )
 {
-  // Concatenate the STK rawwave path to the rawwave file
-  sine_ = new WaveLoop( ( Stk::rawwavePath() + "sinewave.raw").c_str(), true );
-  sine_->setFrequency( 2800.0 );
+  sine_.setFrequency( 2800.0 );
 
   can_.setRadius( CAN_RADIUS );
   can_.setPosition(0, 0, 0); // set can location
@@ -56,29 +56,31 @@ Whistle :: Whistle()
   envelope_.setRate( ENV_RATE );
   envelope_.keyOn();
 
-	fippleFreqMod_ = 0.5;
-	fippleGainMod_ = 0.5;
-	blowFreqMod_ = 0.25;
-	noiseGain_ = 0.125;
-	baseFrequency_ = 2000;
+  fippleFreqMod_ = 0.5;
+  fippleGainMod_ = 0.5;
+  blowFreqMod_ = 0.25;
+  noiseGain_ = 0.125;
+  baseFrequency_ = 2000;
 
-	tickSize_ = NORM_TICK_SIZE;
-	canLoss_ = NORM_CAN_LOSS;
+  tickSize_ = NORM_TICK_SIZE;
+  canLoss_ = NORM_CAN_LOSS;
 
-	subSample_ = 1;
-	subSampCount_ = subSample_;
+  subSample_ = 1;
+  subSampCount_ = subSample_;
 }
 
-Whistle :: ~Whistle()
+Whistle :: ~Whistle( void )
 {
-  delete sine_;
+#ifdef WHISTLE_ANIMATION
+  printf("Exit, Whistle bye bye!!\n");
+#endif
 }
 
-void Whistle :: clear()
+void Whistle :: clear( void )
 {
 }
 
-void Whistle :: setFrequency(StkFloat frequency)
+void Whistle :: setFrequency( StkFloat frequency )
 {
   StkFloat freakency = frequency * 4;  // the whistle is a transposing instrument
   if ( frequency <= 0.0 ) {
@@ -90,19 +92,19 @@ void Whistle :: setFrequency(StkFloat frequency)
   baseFrequency_ = freakency;
 }
 
-void Whistle :: startBlowing(StkFloat amplitude, StkFloat rate)
+void Whistle :: startBlowing( StkFloat amplitude, StkFloat rate )
 {
-	envelope_.setRate( ENV_RATE );
-	envelope_.setTarget( amplitude );
+  envelope_.setRate( ENV_RATE );
+  envelope_.setTarget( amplitude );
 }
 
-void Whistle :: stopBlowing(StkFloat rate)
+void Whistle :: stopBlowing( StkFloat rate )
 {
   envelope_.setRate( rate );
   envelope_.keyOff();
 }
 
-void Whistle :: noteOn(StkFloat frequency, StkFloat amplitude)
+void Whistle :: noteOn( StkFloat frequency, StkFloat amplitude )
 {
   this->setFrequency( frequency );
   this->startBlowing( amplitude*2.0 ,amplitude * 0.2 );
@@ -112,7 +114,7 @@ void Whistle :: noteOn(StkFloat frequency, StkFloat amplitude)
 #endif
 }
 
-void Whistle :: noteOff(StkFloat amplitude)
+void Whistle :: noteOff( StkFloat amplitude )
 {
   this->stopBlowing( amplitude * 0.02 );
 
@@ -124,22 +126,22 @@ void Whistle :: noteOff(StkFloat amplitude)
 
 int frameCount = 0;
 
-StkFloat Whistle :: tick()
+StkFloat Whistle :: tick( unsigned int )
 {
   StkFloat soundMix, tempFreq;
   StkFloat envOut = 0, temp, temp1, temp2, tempX, tempY;
   double phi, cosphi, sinphi;
   double gain = 0.5, mod = 0.0;
 
-	if ( --subSampCount_ <= 0 )	{
-		tempVectorP_ = pea_.getPosition();
-		subSampCount_ = subSample_;
-		temp = bumper_.isInside( tempVectorP_ );
+  if ( --subSampCount_ <= 0 )	{
+    tempVectorP_ = pea_.getPosition();
+    subSampCount_ = subSample_;
+    temp = bumper_.isInside( tempVectorP_ );
 #ifdef WHISTLE_ANIMATION
     frameCount += 1;
     if ( frameCount >= (1470 / subSample_) ) {
       frameCount = 0;
-      printf("%f %f %f\n",tempVectorP->getX(),tempVectorP->getY(),envOut);
+      printf("%f %f %f\n",tempVectorP_->getX(),tempVectorP_->getY(),envOut);
       fflush(stdout);
     }
 #endif
@@ -151,7 +153,7 @@ StkFloat Whistle :: tick()
       pea_.addVelocity( tempX, tempY, 0 ); 
       pea_.tick( tickSize_ );
     }
-        
+
     mod  = exp(-temp * 0.01);	  // exp. distance falloff of fipple/pea effect
     temp = onepole_.tick(mod);	// smooth it a little
     gain = (1.0 - (fippleGainMod_*0.5)) + (2.0 * fippleGainMod_ * temp);
@@ -163,8 +165,8 @@ StkFloat Whistle :: tick()
     tempFreq = 1.0 + fippleFreqMod_*(0.25-temp) + blowFreqMod_*(envOut-1.0);
     tempFreq *= baseFrequency_;
 
-    sine_->setFrequency(tempFreq);
-    
+    sine_.setFrequency(tempFreq);
+
     tempVectorP_ = pea_.getPosition();
     temp = can_.isInside(tempVectorP_);
     temp  = -temp;       // We know (hope) it's inside, just how much??
@@ -202,32 +204,22 @@ StkFloat Whistle :: tick()
       tempX = 0.0;
       tempY = 0.0;
     }
-    
+
     temp = (0.9 + 0.1*subSample_*noise_.tick()) * envOut * 0.6 * tickSize_;
     pea_.addVelocity( temp * tempX, (temp*tempY) - (GRAVITY*tickSize_), 0 );
     pea_.tick( tickSize_ );
 
     // bumper_.tick(0.0);
-	}
+  }
 
-	temp = envOut * envOut * gain / 2;
-	soundMix = temp * ( sine_->tick() + ( noiseGain_*noise_.tick() ) );
-	lastOutput_ = 0.25 * soundMix; // should probably do one-zero filter here
+  temp = envOut * envOut * gain / 2;
+  soundMix = temp * ( sine_.tick() + ( noiseGain_*noise_.tick() ) );
+  lastFrame_[0] = 0.20 * soundMix; // should probably do one-zero filter here
 
-	return lastOutput_;
+  return lastFrame_[0];
 }
 
-StkFloat *Whistle :: tick(StkFloat *vector, unsigned int vectorSize)
-{
-  return Instrmnt::tick( vector, vectorSize );
-}
-
-StkFrames& Whistle :: tick( StkFrames& frames, unsigned int channel )
-{
-  return Instrmnt::tick( frames, channel );
-}
-
-void Whistle :: controlChange(int number, StkFloat value)
+void Whistle :: controlChange( int number, StkFloat value )
 {
   StkFloat norm = value * ONE_OVER_128;
   if ( norm < 0 ) {
@@ -241,26 +233,30 @@ void Whistle :: controlChange(int number, StkFloat value)
     handleError( StkError::WARNING );
   }
 
-  if (number == __SK_NoiseLevel_) // 4
+  if ( number == __SK_NoiseLevel_ ) // 4
     noiseGain_ = 0.25 * norm;
-  else if (number == __SK_ModFrequency_) // 11
+  else if ( number == __SK_ModFrequency_ ) // 11
     fippleFreqMod_ = norm;
-  else if (number == __SK_ModWheel_) // 1
+  else if ( number == __SK_ModWheel_ ) // 1
     fippleGainMod_ = norm;
-  else if (number == __SK_AfterTouch_Cont_) // 128
+  else if ( number == __SK_AfterTouch_Cont_ ) // 128
     envelope_.setTarget( norm * 2.0 );
-  else if (number == __SK_Breath_) // 2
+  else if ( number == __SK_Breath_ ) // 2
     blowFreqMod_ = norm * 0.5;
-  else if (number == __SK_Sustain_)	 // 64
-	  if (value < 1.0) subSample_ = 1;
+  else if ( number == __SK_Sustain_ )	{ // 64
+    subSample_ = (int) value;
+    if ( subSample_ < 1.0 ) subSample_ = 1;
+    envelope_.setRate( ENV_RATE / subSample_ );
+  }
   else {
     errorString_ << "Whistle::controlChange: undefined control number (" << number << ")!";
     handleError( StkError::WARNING );
   }
 
 #if defined(_STK_DEBUG_)
-    errorString_ << "Whistle::controlChange: number = " << number << ", value = " << value << '.';
-    handleError( StkError::DEBUG_WARNING );
+  errorString_ << "Whistle::controlChange: number = " << number << ", value = " << value << '.';
+  handleError( StkError::DEBUG_WARNING );
 #endif
 }
 
+} // stk namespace
